<?php 
/*
	Plugin Name: Head Meta Date
	Plugin URI: http://wordpress.org/extend/plugins/head-meta-date/
	Description: Adds a set of date &lt;meta&gt; tags to the &lt;head&gt; section of all posts &amp; pages.
	Author: Patrice Chassaing
	Author URI: http://p.chas.free.fr/
	Version: 20130412
	License: GPL v2
	Usage: Visit the plugin's settings page to configure your options.
	Tags: meta, head, date, wp_head, customize, author, publisher, language
*/

// NO EDITING REQUIRED - PLEASE SET PREFERENCES IN THE WP ADMIN!

$hmdate_plugin  = __('Head Meta Date');
$hmdate_options = get_option('hmdate_options');
$hmdate_path    = plugin_basename(__FILE__); // 'head-meta-date/head-meta-date.php';
$hmdate_homeurl = 'http://wordpress.org/extend/plugins/head-meta-date/';
$hmdate_version = '20130412';

// require minimum version of WordPress
add_action('admin_init', 'hmdate_require_wp_version');
function hmdate_require_wp_version() {
	global $wp_version, $hmdate_path, $hmdate_plugin;
	if (version_compare($wp_version, '3.3.1', '<')) {
		if (is_plugin_active($hmdate_path)) {
			deactivate_plugins($hmdate_path);
			$msg =  '<strong>' . $hmdate_plugin . '</strong> ' . __('requires WordPress 3.3.1 or higher, and has been deactivated! But you can try an older version by modifying line 26 in head-meta-date.php') . '<br />';
			$msg .= __('Please return to the ') . '<a href="' . admin_url() . '">' . __('WordPress Admin area') . '</a> ' . __('to upgrade WordPress and try again.');
			wp_die($msg);
		}
	}
}

// insert head meta date
add_action('wp_head', 'head_meta_date');
function head_meta_date() { 
	echo hmdate_display_content();
}

// shortcode to display head meta date
add_shortcode('head_meta_date','hmdate_shortcode');
function hmdate_shortcode() {
	$get_meta_date = hmdate_display_content();
	$the_meta_date = str_replace(array('>', '<'), array('&gt;','&lt;'), $get_meta_date);
	return $the_meta_date;
}

// display head meta date
function hmdate_display_content() {
	global $hmdate_options;
	$hmdate_output = '';
	$hmdate_enable = $hmdate_options['hmdate_enable']; 
	$hmdate_format = $hmdate_options['hmdate_format'];
	if ($hmdate_format == false) {
		$close_tag = '" />' . "\n";
	} else {
		$close_tag = '">' . "\n";
	}
	if ($hmdate_enable == true) {		
		$hmdate_output = "\n" . '<!-- META Tags added by Head Meta Date WordPress plugin. Get it at: http://wordpress.org/extend/plugins/head-meta-date/ -->' . "\n";
		//<meta http-equiv="Date" content="Wed, 16 Feb 2011 22:34:13 GMT">
		//<meta http-equiv="Last-Modified" content="Wed, 17 Feb 2011 12:34:13 GMT">
		//<meta name="CreateDate" content="Wed, 16 Feb 2011 22:34:13 GMT">
		//<meta name="Last-Update" content="Wed, 17 Feb 2011 12:34:13 GMT">
 
  function translate_day_to_en( $str ) {
        $en = array( 'Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday' );
        $en_short = array( 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat' );         
        $str = $en_short[intval($str)]; 
        return $str;
    }
   function translate_month_to_en( $str ) {
        $en = array( 'January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December' );
        $en_short = array( 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'June', 'July', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec' );
        $str = $en_short[intval($str)-1];
        return $str;
    }
   function get_post_modified_time_real($format) {
    global $post;
    return date($format, strtotime($post->post_modified));
    }
  
  if ($post_date=='' && ( !is_single() && !is_page() && !is_attachment() ) ){
    $post_date = translate_day_to_en(date('w')).', '.date('j').' '.translate_month_to_en(date('n')).' '.date('Y').' '.date('H:i:s e');
    $post_last_modified = translate_day_to_en(date('w')).', '.date('j').' '.translate_month_to_en(date('n')).' '.date('Y').' '.date('H:i:s e'); 
  }
  else {
    $post_date = translate_day_to_en(get_the_time('w')).', '.get_the_time('j').' '.translate_month_to_en(get_the_time('n')).' '.get_the_time('Y').' '.get_the_time('H:i:s e');
    $post_last_modified = translate_day_to_en(get_post_modified_time_real('w')).', '.get_post_modified_time_real('j').' '.translate_month_to_en(get_post_modified_time_real('n')).' '.get_post_modified_time_real('Y').' '.get_post_modified_time_real('H:i:s e');
  }                                                     
  
	$post_createdate = $post_date;
  $post_last_update = $post_last_modified;
    if ($hmdate_options['hmdate_date']   == '')            {$hmdate_options['hmdate_date']=$post_date;}    
		if ($hmdate_options['hmdate_last_modified']     == '') {$hmdate_options['hmdate_last_modified']=$post_last_modified;}
		if ($hmdate_options['hmdate_createdate']   == '')      {$hmdate_options['hmdate_createdate']=$post_createdate;}
		if ($hmdate_options['hmdate_last_update']  == '')      {$hmdate_options['hmdate_last_update']=$post_last_update;}
    
		if ($hmdate_options['hmdate_date']   !== '')            {$hmdate_output .= '<meta http-equiv="date" content="'       . $hmdate_options['hmdate_date']   . $close_tag;}    
		if ($hmdate_options['hmdate_last_modified']     !== '') {$hmdate_output .= '<meta http-equiv="last-modified" content="'         . $hmdate_options['hmdate_last_modified']     . $close_tag;}
		if ($hmdate_options['hmdate_createdate']   !== '')      {$hmdate_output .= '<meta name="createdate" content="' . $hmdate_options['hmdate_createdate']   . $close_tag;}
		if ($hmdate_options['hmdate_last_update']  !== '')      {$hmdate_output .= '<meta name="last-update" content="'      . $hmdate_options['hmdate_last_update']  . $close_tag;}
	}
	return $hmdate_output;
}

// insert custom content
add_action('wp_head', 'hmdate_custom_content');
function hmdate_custom_content() {
	global $hmdate_options;
	//if ($hmdate_options['hmdate_custom'] !== '' &&  is_page()) 
	echo $hmdate_options['hmdate_custom'] . "\n";
}

// shortcode to display custom content
add_shortcode('hmdate_custom','hmdate_custom_shortcode');
function hmdate_custom_shortcode() {
	global $hmdate_options;
	if ($hmdate_options['hmdate_custom'] !== '') {
		$get_custom_data = $hmdate_options['hmdate_custom'];
		$the_custom_data = str_replace(array('>', '<'), array('&gt;','&lt;'), $get_custom_data);
		return $the_custom_data;
	}
}

// display settings link on plugin page
add_filter ('plugin_action_links', 'hmdate_plugin_action_links', 10, 2);
function hmdate_plugin_action_links($links, $file) {
	global $hmdate_path;
	if ($file == $hmdate_path) {
		$hmdate_links = '<a href="' . get_admin_url() . 'options-general.php?page=' . $hmdate_path . '">' . __('Settings') .'</a>';
		array_unshift($links, $hmdate_links);
	}
	return $links;
}

// delete plugin settings
function hmdate_delete_plugin_options() {
	delete_option('hmdate_options');
}
if ($hmdate_options['default_options'] == 1) {
	register_uninstall_hook (__FILE__, 'hmdate_delete_plugin_options');
}

// define default settings
register_activation_hook (__FILE__, 'hmdate_add_defaults');
function hmdate_add_defaults() {
	// metas

	$post_date = "Wed, 16 Feb 2011 22:34:13 GMT";
	$post_last_modified = "Wed, 16 Feb 2011 22:34:13 GMT";
	$post_createdate = $post_date;
  $post_last_update = $post_last_modified;
	
	$tmp = get_option('hmdate_options');
	if(($tmp['default_options'] == '1') || (!is_array($tmp))) {
		$arr = array(
			'default_options' => 0,
			'hmdate_date'    => $post_date,
			'hmdate_last_modified'      => $post_last_modified,
			'hmdate_createdate'    => $post_createdate,
			'hmdate_last_update'   => $post_last_update,
			'hmdate_enable'      => 1,
			'hmdate_format'      => 1
		);
		update_option('hmdate_options', $arr);
	}
}

// whitelist settings
add_action ('admin_init', 'hmdate_init');
function hmdate_init() {
	register_setting('hmdate_plugin_options', 'hmdate_options', 'hmdate_validate_options');
}

// sanitize and validate input
function hmdate_validate_options($input) {

	if (!isset($input['default_options'])) $input['default_options'] = null;
	$input['default_options'] = ($input['default_options'] == 1 ? 1 : 0);
	//Date Last-Modified CreateDate Last-Update
	$input['hmdate_date']   = wp_filter_nohtml_kses($input['hmdate_date']);
	$input['hmdate_last_modified']     = wp_filter_nohtml_kses($input['hmdate_last_modified']);
	$input['hmdate_createdate']   = wp_filter_nohtml_kses($input['hmdate_createdate']);
	$input['hmdate_last_update']  = wp_filter_nohtml_kses($input['hmdate_last_update']);

	if (!isset($input['hmdate_enable'])) $input['hmdate_enable'] = null;
	$input['hmdate_enable'] = ($input['hmdate_enable'] == 1 ? 1 : 0);

	// dealing with kses
	global $allowedposttags;
	$allowed_atts = array(
		'align'=>array(), 'class'=>array(), 'id'=>array(), 'dir'=>array(), 'lang'=>array(), 'style'=>array(), 'label'=>array(), 'url'=>array(), 
		'xml:lang'=>array(), 'src'=>array(), 'alt'=>array(), 'name'=>array(), 'content'=>array(), 'http-equiv'=>array(), 'profile'=>array()
		);
	$allowedposttags['strong'] = $allowed_atts;
	$allowedposttags['script'] = $allowed_atts;
	$allowedposttags['style'] = $allowed_atts;
	$allowedposttags['small'] = $allowed_atts;
	$allowedposttags['span'] = $allowed_atts;
	$allowedposttags['meta'] = $allowed_atts;
	$allowedposttags['item'] = $allowed_atts;
	$allowedposttags['base'] = $allowed_atts;
	$allowedposttags['link'] = $allowed_atts;
	$allowedposttags['abbr'] = $allowed_atts;
	$allowedposttags['code'] = $allowed_atts;
	$allowedposttags['div'] = $allowed_atts;
	$allowedposttags['img'] = $allowed_atts;
	$allowedposttags['h1'] = $allowed_atts;
	$allowedposttags['h2'] = $allowed_atts;
	$allowedposttags['h3'] = $allowed_atts;
	$allowedposttags['h4'] = $allowed_atts;
	$allowedposttags['h5'] = $allowed_atts;
	$allowedposttags['ol'] = $allowed_atts;
	$allowedposttags['ul'] = $allowed_atts;
	$allowedposttags['li'] = $allowed_atts;
	$allowedposttags['em'] = $allowed_atts;
	$allowedposttags['p'] = $allowed_atts;
	$allowedposttags['a'] = $allowed_atts;

	$input['hmdate_custom'] = wp_kses_post($input['hmdate_custom'], $allowedposttags);

	if (!isset($input['hmdate_format'])) $input['hmdate_format'] = null;
	$input['hmdate_format'] = ($input['hmdate_format'] == 1 ? 1 : 0);

	return $input;
}

// add the options page
add_action ('admin_menu', 'hmdate_add_options_page');
function hmdate_add_options_page() {
	global $hmdate_plugin;
	add_options_page($hmdate_plugin, $hmdate_plugin, 'manage_options', __FILE__, 'hmdate_render_form');
}

// create the options page
function hmdate_render_form() {
	global $hmdate_plugin, $hmdate_options, $hmdate_path, $hmdate_homeurl, $hmdate_version; ?>

	<style type="text/css">
		.mm-panel-overview { padding-left: 140px; background: url(<?php echo plugins_url(); ?>/head-meta-date/hmd-logo.png) no-repeat 15px 0; }

		#mm-plugin-options h2 small { font-size: 60%; }
		#mm-plugin-options h3 { cursor: pointer; }
		#mm-plugin-options h4, 
		#mm-plugin-options p { margin: 15px; line-height: 18px; }
		#mm-plugin-options ul { margin: 15px 15px 25px 40px; }
		#mm-plugin-options li { margin: 10px 0; list-style-type: disc; }
		#mm-plugin-options abbr { cursor: help; border-bottom: 1px dotted #dfdfdf; }

		.mm-table-wrap { margin: 15px; }
		.mm-table-wrap td { padding: 5px 10px; vertical-align: middle; }
		.mm-table-wrap .widefat th { padding: 10px 15px; vertical-align: middle; }
		.mm-table-wrap .widefat td { padding: 10px; vertical-align: middle; }

		.mm-item-caption { margin: 3px 0 0 3px; font-size: 11px; color: #777; line-height: 17px; }
		.mm-code-example { margin: 10px 0 20px 0; }
		.mm-code-example div { margin-left: 15px; }
		.mm-code-example pre { margin-left: 30px; }
		.mm-code { background-color: #fafae0; color: #333; font-size: 14px; }

		#setting-error-settings_updated { margin: 10px 0; }
		#setting-error-settings_updated p { margin: 5px; }
		#mm-plugin-options .button-primary { margin: 0 0 15px 15px; }

		#mm-panel-toggle { margin: 5px 0; }
		#mm-credit-info { margin-top: -5px; }
		#mm-iframe-wrap { width: 100%; height: 125px; overflow: hidden; }
		#mm-iframe-wrap iframe { width: 100%; height: 100%; overflow: hidden; margin: 0; padding: 0; }
	</style>

	<div id="mm-plugin-options" class="wrap">
		<?php screen_icon(); ?>

		<h2><?php echo $hmdate_plugin; ?> <small><?php echo 'v' . $hmdate_version; ?></small></h2>
		<div id="mm-panel-toggle"><a href="<?php get_admin_url() . 'options-general.php?page=' . $hmdate_path; ?>"><?php _e('Toggle all panels'); ?></a></div>

		<form method="post" action="options.php">
			<?php $hmdate_options = get_option('hmdate_options'); settings_fields('hmdate_plugin_options'); ?>

			<div class="metabox-holder">
				<div class="meta-box-sortables ui-sortable">
					<div id="mm-panel-overview" class="postbox">
						<h3><?php _e('Overview'); ?></h3>
						<div class="toggle default-hidden">
							<div class="mm-panel-overview">
								<p>
									<strong><?php echo $hmdate_plugin; ?></strong> <?php _e('(HMD) adds assorted <code>&lt;head&gt;</code> tags and more to the <code>&lt;head&gt;</code> section of all posts &amp; pages.'); ?>
									<?php _e('Optionally includes custom text/markup in the <code>&lt;head&gt;</code> section.'); ?>
								</p>
								<ul>
									<li><?php _e('To configure the plugin, visit'); ?> <a id="mm-panel-primary-link" href="#mm-panel-primary"><?php _e('Options'); ?></a>.</li>
									<li><?php _e('For a live preview of the meta tags, visit'); ?> <a id="mm-panel-secondary-link" href="#mm-panel-secondary"><?php _e('Preview'); ?></a>.</li>
									<li><?php _e('To restore default settings, visit'); ?> <a id="mm-restore-settings-link" href="#mm-restore-settings"><?php _e('Restore Default Options'); ?></a>.</li>
									<li><?php _e('For more information check the <code>readme.txt</code> and'); ?> <a href="<?php echo $hmdate_homeurl; ?>"><?php _e('Head MetaDate Homepage'); ?></a>.</li>
								</ul>
							</div>
						</div>
					</div>
					<div id="mm-panel-primary" class="postbox">
						<h3><?php _e('Options'); ?></h3>
						<div class="toggle<?php if (!isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<h4><?php _e('General options'); ?></h4>
							<p><?php _e('Here you may enable/disable meta output and choose either <abbr title="Hypertext Markup Language">HTML</abbr> or <abbr title="eXtensible Hypertext Markup Language">XHTML</abbr> formatting.'); ?></p>
							<div class="mm-table-wrap">
								<table class="widefat mm-table">
									<tr>
										<th scope="row"><label class="description" for="hmdate_options[hmdate_enable]"><?php _e('Enable plugin?'); ?></label></th>
										<td><input type="checkbox" name="hmdate_options[hmdate_enable]" value="1" <?php if (isset($hmdate_options['hmdate_enable'])) { checked('1', $hmdate_options['hmdate_enable']); } ?> /> 
										<span class="mm-item-caption"><?php _e('Check this box if you want to enable output of your customized meta tags.'); ?></span></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="hmdate_options[hmdate_format]"><?php _e('HTML Format?'); ?></label></th>
										<td><input type="checkbox" name="hmdate_options[hmdate_format]" value="1" <?php if (isset($hmdate_options['hmdate_format'])) { checked('1', $hmdate_options['hmdate_format']); } ?> /> 
										<span class="mm-item-caption"><?php _e('Uncheck this box if you want to enable <abbr title="eXtensible Hypertext Markup Language">XHTML</abbr> format. Leave checked for the default (<abbr title="Hypertext Markup Language">HTML</abbr>).'); ?></span></td>
									</tr>
								</table>
							</div>
							<h4><?php _e('Meta tags'); ?></h4>
							<p><?php _e('Here you may specify date values for your <code>&lt;meta&gt;</code> tags. Leave blank to disable specific tags. Date must be written as `Wed, 16 Feb 2011 22:34:13 GMT` format.'); ?></p>
							<div class="mm-table-wrap">
								<table class="widefat mm-table">
									<tr><!-- //Date Last-Modified CreateDate Last-Update -->
										<th scope="row"><label class="description" for="hmdate_options[hmdate_date]"><?php _e('Meta date'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="hmdate_options[hmdate_date]" value="<?php echo $hmdate_options['hmdate_date']; ?>" />
										<div class="mm-item-caption"><?php _e('Indicate the create date of the post.'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="hmdate_options[hmdate_last_modified]"><?php _e('Meta last modified'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="hmdate_options[hmdate_last_modified]" value="<?php echo $hmdate_options['hmdate_last_modified']; ?>" />
										<div class="mm-item-caption"><?php _e('Indicate the last modified date of the post.'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="hmdate_options[hmdate_createdate]"><?php _e('Meta create date'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="hmdate_options[hmdate_createdate]" value="<?php echo $hmdate_options['hmdate_createdate']; ?>" />
										<div class="mm-item-caption"><?php _e('Indicate the create date of the post.'); ?></div></td>
									</tr>
									<tr>
										<th scope="row"><label class="description" for="hmdate_options[hmdate_last_update]"><?php _e('Meta last update'); ?></label></th>
										<td><input type="text" size="50" maxlength="200" name="hmdate_options[hmdate_last_update]" value="<?php echo $hmdate_options['hmdate_last_update']; ?>" />
										<div class="mm-item-caption"><?php _e('Indicate the last update date of the post.'); ?></div></td>
									</tr>
								</table>
							</div>
							<input type="submit" class="button-primary" value="<?php _e('Save Settings'); ?>" />
						</div>
					</div>
					<div id="mm-panel-secondary" class="postbox">
						<h3><?php _e('Preview'); ?></h3>
						<div class="toggle<?php if (!isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<p><?php _e('Here is a preview of your meta tags and custom content.'); ?></p>
							<div class="mm-code-example">
								<h4><?php _e('Meta tags'); ?></h4>
								<div><?php _e('(display using <code>[head_meta_date]</code> shortcode)'); ?></div>
								<pre><?php echo do_shortcode('[head_meta_date]'); ?></pre>
								<h4><?php _e('More infos'); ?></h4>
								<ul>
									<li><?php _e('For more information on document meta tags (W3C):'); ?> <a href="http://www.w3.org/wiki/HTML/Elements/meta" title="HTML/Elements/meta (new window)" target="_blank">http://www.w3.org/wiki/HTML/Elements/meta</a></li>
								</ul>
							</div>
						</div>
					</div>
					<div id="mm-restore-settings" class="postbox">
						<h3><?php _e('Restore Default Options'); ?></h3>
						<div class="toggle<?php if (!isset($_GET["settings-updated"])) { echo ' default-hidden'; } ?>">
							<p>
								<input name="hmdate_options[default_options]" type="checkbox" value="1" id="mm_restore_defaults" <?php if (isset($hmdate_options['default_options'])) { checked('1', $hmdate_options['default_options']); } ?> /> 
								<label class="description" for="hmdate_options[default_options]"><?php _e('Restore default options upon plugin deactivation/reactivation.'); ?></label>
							</p>
							<p>
								<small>
									<?php _e('<strong>Tip:</strong> leave this option unchecked to remember your settings. Or, to go ahead and restore all default options, check the box, save your settings, and then deactivate/reactivate the plugin.'); ?>
								</small>
							</p>
							<input type="submit" class="button-primary" value="<?php _e('Save Settings'); ?>" />
						</div>
					</div>
					<div id="mm-panel-current" class="postbox">
						<h3><?php _e('Updates &amp; Info'); ?></h3>
						<div class="toggle default-hidden">
							<div id="mm-iframe-wrap">
              <p>
								Thank you for using Head Meta Date.<br/>
                I created this plugin in a short period of time, thank you to forgive me for any errors and report them to me.<br/>
                Your opinion interests me.<br/>
                HAGD.
              </p>  
							</div>
						</div>
					</div>
				</div>
			</div>
			<div id="mm-credit-info">
				<a target="_blank" href="<?php echo $hmdate_homeurl; ?>" title="<?php echo $hmdate_plugin; ?> Homepage"><?php echo $hmdate_plugin; ?></a> by 
				<a target="_blank" href="http://fr.linkedin.com/pub/patrice-chassaing/6/631/464" title="Patrice Chassaing is on LinkedIn">Patrice Chassaing</a> @ 
				<a target="_blank" href="http://p.chas.free.fr/" title="Patrice Chassaing web site">is web site</a>
			</div>
		</form>
	</div>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			// toggle panels
			jQuery('.default-hidden').hide();
			jQuery('#mm-panel-toggle a').click(function(){
				jQuery('.toggle').slideToggle(300);
				return false;
			});
			jQuery('h3').click(function(){
				jQuery(this).next().slideToggle(300);
			});
			jQuery('#mm-panel-primary-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-panel-primary .toggle').slideToggle(300);
				return true;
			});
			jQuery('#mm-panel-secondary-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-panel-secondary .toggle').slideToggle(300);
				return true;
			});
			jQuery('#mm-restore-settings-link').click(function(){
				jQuery('.toggle').hide();
				jQuery('#mm-restore-settings .toggle').slideToggle(300);
				return true;
			});
			// prevent accidents
			if(!jQuery("#mm_restore_defaults").is(":checked")){
				jQuery('#mm_restore_defaults').click(function(event){
					var r = confirm("<?php _e('Are you sure you want to restore all default options? (this action cannot be undone)'); ?>");
					if (r == true){  
						jQuery("#mm_restore_defaults").attr('checked', true);
					} else {
						jQuery("#mm_restore_defaults").attr('checked', false);
					}
				});
			}
		});
	</script>

<?php } ?>